#!/usr/bin/env bash

echo "Repository name: "$DRONE_REPO_NAME
echo "Repository owner: "$DRONE_REPO_OWNER

echo "Generating and deploying documentation for user $DRONE_REPO_OWNER and repository $DRONE_REPO_NAME"

mkdir -p /docs/doxygen/
mkdir -p /docs/docusaurus/

DOCDIR="Documentation"
[ -d "/drone/src/documentation" ] && DOCDIR="documentation" 

[ -d "/drone/src/$DOCDIR/doxygen" ] && cd /drone/src/$DOCDIR/doxygen && doxygen Doxyfile
[ -d "/drone/src/$DOCDIR/docusaurus" ] && cd /drone/src/$DOCDIR/docusaurus && npm install && npm run build

swaggerfile=$(find /docs -maxdepth 1 -type f -iname "swagger.*" -printf "%f" -quit)
if [[ ! -z "$swaggerfile" ]]
then
    echo "<!DOCTYPE html>
<html>
  <head>
    <meta http-equiv="Refresh" content=\"0; url=/swagger?url=/documentation/$DRONE_REPO_OWNER/swagger/$DRONE_REPO_NAME/$swaggerfile\" />
  </head>
  <body>
    <p>Suivez <a href=\"/swagger?url=/swagger?url=/documentation/$DRONE_REPO_OWNER/swagger/$DRONE_REPO_NAME/$swaggerfile\">ce lien</a>.</p>
  </body>
</html>" > /docs/CLICKME.html
fi

cd /drone/src/$DOCDIR

[ -d "/drone/src/$DOCDIR/doxygen" ] && rsync --rsync-path="mkdir -p /usr/share/nginx/html/$DRONE_REPO_OWNER/doxygen/$DRONE_REPO_NAME/ && rsync" -e "ssh -o StrictHostKeyChecking=no" -avz --delete /docs/doxygen/ root@nginx:/usr/share/nginx/html/$DRONE_REPO_OWNER/doxygen/$DRONE_REPO_NAME/
[ -d "/docs/CLICKME.html" ] && rsync --rsync-path="mkdir -p /usr/share/nginx/html/$DRONE_REPO_OWNER/swagger/$DRONE_REPO_NAME/ && rsync" -e "ssh -o StrictHostKeyChecking=no" -avz --delete /docs/{swagger.*,CLICKME.html} root@nginx:/usr/share/nginx/html/$DRONE_REPO_OWNER/swagger/$DRONE_REPO_NAME/
[ -d "/drone/src/$DOCDIR/docusaurus" ] && rsync --rsync-path="mkdir -p /usr/share/nginx/html/$DRONE_REPO_OWNER/docusaurus/$DRONE_REPO_NAME/ && rsync" -e "ssh -o StrictHostKeyChecking=no" -avz --delete docusaurus/build/ root@nginx:/usr/share/nginx/html/$DRONE_REPO_OWNER/docusaurus/$DRONE_REPO_NAME/

exit 0